# Welcome to Pokie

[![Tests](https://github.com/oddbit-project/pokie/workflows/Tests/badge.svg?branch=master)](https://github.com/oddbit-project/pokie/actions)
[![pypi](https://img.shields.io/pypi/v/pokie.svg)](https://pypi.org/project/pokie/)
[![license](https://img.shields.io/pypi/l/pokie.svg)](https://github.com/oddbit-project/pokie/blob/master/LICENSE)

Pokie is a Flask application boilerplate, using [Rick](https://github.com/oddbit-project/rick) and 
[Rick-db](https://github.com/oddbit-project/rick_db) components.
